@@ -10,7 +10,7 @@
 
 module RbConfig
   RUBY_VERSION.start_with?("2.7.") or
-    raise "ruby lib version (2.7.6) doesn't match executable version (#{RUBY_VERSION})"
+    raise "ruby lib version (2.7.7) doesn't match executable version (#{RUBY_VERSION})"
 
   # Ruby installed directory.
   TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/2.7/aarch64-openbsd")
@@ -21,9 +21,9 @@ module RbConfig
   CONFIG["DESTDIR"] = DESTDIR
   CONFIG["MAJOR"] = "2"
   CONFIG["MINOR"] = "7"
-  CONFIG["TEENY"] = "6"
-  CONFIG["PATCHLEVEL"] = "219"
-  CONFIG["INSTALL"] = '/usr/obj/ports/ruby-2.7.6/bin/install -c'
+  CONFIG["TEENY"] = "7"
+  CONFIG["PATCHLEVEL"] = "221"
+  CONFIG["INSTALL"] = '/build/tmp/pobj//ruby-2.7.7/bin/install -c'
   CONFIG["EXEEXT"] = ""
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
   CONFIG["ruby_install_name"] = "$(RUBY_BASE_NAME)27"
@@ -122,6 +122,7 @@ module RbConfig
   CONFIG["RPATHFLAG"] = " -Wl,-rpath,%1$-s"
   CONFIG["LIBPATHFLAG"] = " -L%1$-s"
   CONFIG["LINK_SO"] = ""
+  CONFIG["ADDITIONAL_DLDFLAGS"] = ""
   CONFIG["ASMEXT"] = "S"
   CONFIG["LIBEXT"] = "a"
   CONFIG["DLEXT2"] = ""
@@ -149,9 +150,9 @@ module RbConfig
   CONFIG["DOT"] = ""
   CONFIG["MAKEDIRS"] = "mkdir -p"
   CONFIG["MKDIR_P"] = "mkdir -p"
-  CONFIG["INSTALL_DATA"] = "/usr/obj/ports/ruby-2.7.6/bin/install -c -m 644"
-  CONFIG["INSTALL_SCRIPT"] = "/usr/obj/ports/ruby-2.7.6/bin/install -c -m 755"
-  CONFIG["INSTALL_PROGRAM"] = "/usr/obj/ports/ruby-2.7.6/bin/install -c  -m 755"
+  CONFIG["INSTALL_DATA"] = "/build/tmp/pobj//ruby-2.7.7/bin/install -c -m 644"
+  CONFIG["INSTALL_SCRIPT"] = "/build/tmp/pobj//ruby-2.7.7/bin/install -c -m 755"
+  CONFIG["INSTALL_PROGRAM"] = "/build/tmp/pobj//ruby-2.7.7/bin/install -c  -m 755"
   CONFIG["SET_MAKE"] = ""
   CONFIG["LN_S"] = "ln -s"
   CONFIG["NM"] = "nm"
@@ -175,10 +176,10 @@ module RbConfig
   CONFIG["GNU_LD"] = "no"
   CONFIG["LD"] = "ld"
   CONFIG["GCC"] = "yes"
-  CONFIG["CXXFLAGS"] = "-O2 -pipe -g"
-  CONFIG["CXX"] = "c++"
   CONFIG["EGREP"] = "/usr/bin/egrep"
   CONFIG["GREP"] = "/usr/bin/grep"
+  CONFIG["CXXFLAGS"] = "-O2 -pipe -g"
+  CONFIG["CXX"] = "c++"
   CONFIG["CPP"] = "$(CC) -E"
   CONFIG["OBJEXT"] = "o"
   CONFIG["CPPFLAGS"] = "-DOPENSSL_NO_STATIC_ENGINE -I/usr/local/include $(DEFS) $(cppflags)"
