@@ -10,7 +10,7 @@
 
 module RbConfig
   RUBY_VERSION.start_with?("2.7.") or
-    raise "ruby lib version (2.7.6) doesn't match executable version (#{RUBY_VERSION})"
+    raise "ruby lib version (2.7.7) doesn't match executable version (#{RUBY_VERSION})"
 
   # Ruby installed directory.
   TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/2.7/sparc64-openbsd")
@@ -21,9 +21,9 @@ module RbConfig
   CONFIG["DESTDIR"] = DESTDIR
   CONFIG["MAJOR"] = "2"
   CONFIG["MINOR"] = "7"
-  CONFIG["TEENY"] = "6"
-  CONFIG["PATCHLEVEL"] = "219"
-  CONFIG["INSTALL"] = '/build/tmp/pobj//ruby-2.7.6/bin/install -c'
+  CONFIG["TEENY"] = "7"
+  CONFIG["PATCHLEVEL"] = "221"
+  CONFIG["INSTALL"] = '/build/tmp/pobj//ruby-2.7.7/bin/install -c'
   CONFIG["EXEEXT"] = ""
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
   CONFIG["ruby_install_name"] = "$(RUBY_BASE_NAME)27"
@@ -122,6 +122,7 @@ module RbConfig
   CONFIG["RPATHFLAG"] = " -Wl,-rpath,%1$-s"
   CONFIG["LIBPATHFLAG"] = " -L%1$-s"
   CONFIG["LINK_SO"] = ""
+  CONFIG["ADDITIONAL_DLDFLAGS"] = ""
   CONFIG["ASMEXT"] = "S"
   CONFIG["LIBEXT"] = "a"
   CONFIG["DLEXT2"] = ""
@@ -149,9 +150,9 @@ module RbConfig
   CONFIG["DOT"] = ""
   CONFIG["MAKEDIRS"] = "mkdir -p"
   CONFIG["MKDIR_P"] = "mkdir -p"
-  CONFIG["INSTALL_DATA"] = "/build/tmp/pobj//ruby-2.7.6/bin/install -c -m 644"
-  CONFIG["INSTALL_SCRIPT"] = "/build/tmp/pobj//ruby-2.7.6/bin/install -c -m 755"
-  CONFIG["INSTALL_PROGRAM"] = "/build/tmp/pobj//ruby-2.7.6/bin/install -c -s -m 755"
+  CONFIG["INSTALL_DATA"] = "/build/tmp/pobj//ruby-2.7.7/bin/install -c -m 644"
+  CONFIG["INSTALL_SCRIPT"] = "/build/tmp/pobj//ruby-2.7.7/bin/install -c -m 755"
+  CONFIG["INSTALL_PROGRAM"] = "/build/tmp/pobj//ruby-2.7.7/bin/install -c -s -m 755"
   CONFIG["SET_MAKE"] = ""
   CONFIG["LN_S"] = "ln -s"
   CONFIG["NM"] = "nm"
@@ -175,31 +176,31 @@ module RbConfig
   CONFIG["GNU_LD"] = "yes"
   CONFIG["LD"] = "ld"
   CONFIG["GCC"] = "yes"
-  CONFIG["CXXFLAGS"] = "-O2 -pipe"
-  CONFIG["CXX"] = "c++"
   CONFIG["EGREP"] = "/usr/bin/egrep"
   CONFIG["GREP"] = "/usr/bin/grep"
-  CONFIG["CPP"] = "cc -E"
+  CONFIG["CXXFLAGS"] = "-O2 -pipe"
+  CONFIG["CXX"] = "c++"
+  CONFIG["CPP"] = "$(CC) -E"
   CONFIG["OBJEXT"] = "o"
   CONFIG["CPPFLAGS"] = "-DOPENSSL_NO_STATIC_ENGINE -I/usr/local/include $(DEFS) $(cppflags)"
   CONFIG["LDFLAGS"] = "-L. -L/usr/local/lib -fstack-protector-strong -Wl,-E"
   CONFIG["CFLAGS"] = "-O2 -pipe -fPIC"
   CONFIG["CC"] = "cc -std=gnu99"
-  CONFIG["target_os"] = "openbsd7.1"
+  CONFIG["target_os"] = "openbsd7.2"
   CONFIG["target_vendor"] = "unknown"
   CONFIG["target_cpu"] = "sparc64"
-  CONFIG["target"] = "sparc64-unknown-openbsd7.1"
-  CONFIG["host_os"] = "openbsd7.1"
+  CONFIG["target"] = "sparc64-unknown-openbsd7.2"
+  CONFIG["host_os"] = "openbsd7.2"
   CONFIG["host_vendor"] = "unknown"
   CONFIG["host_cpu"] = "sparc64"
-  CONFIG["host"] = "sparc64-unknown-openbsd7.1"
+  CONFIG["host"] = "sparc64-unknown-openbsd7.2"
   CONFIG["RUBY_VERSION_NAME"] = "$(RUBY_BASE_NAME)-$(ruby_version)"
   CONFIG["RUBYW_BASE_NAME"] = "rubyw"
   CONFIG["RUBY_BASE_NAME"] = "ruby"
-  CONFIG["build_os"] = "openbsd7.1"
+  CONFIG["build_os"] = "openbsd7.2"
   CONFIG["build_vendor"] = "unknown"
   CONFIG["build_cpu"] = "sparc64"
-  CONFIG["build"] = "sparc64-unknown-openbsd7.1"
+  CONFIG["build"] = "sparc64-unknown-openbsd7.2"
   CONFIG["RUBY_PROGRAM_VERSION"] = "$(MAJOR).$(MINOR).$(TEENY)"
   CONFIG["RUBY_API_VERSION"] = "$(MAJOR).$(MINOR)"
   CONFIG["HAVE_GIT"] = "yes"
